from setuptools import setup

setup(name='noobElectric',
      version='0.5',
      description='Tools for Electrical Engineering',
      url='https://github.com/nicholasericksen/noobElectric',
      author='nicholasericksen',
      author_email='ericksennicholas@gmail.com',
      license='MIT',
      packages=['noobee'],
      install_requires=['numpy'],
      zip_safe=False)
